#!/usr/bin/env python3
# -*- coding: utf-8 -*-

CHANGELOG = {
    "2019.10.7": {
        "semvar": "0.0.1",
        "title": "Initial release that does nothing!",
        "changes": [
            ("add", "packaging stuff")
        ]
    }
}
